This function provides a summary of a cpm object, including the
prediction performance and the selected edges.
# S3 method for cpm
summary(object, ..., method = c("pearson", "spearman"), edge_level = 0.5)# S3 method for cpm_summary
print(x, ...)
A list of class cpm_summary containing two elements:
A matrix of prediction performance, including the correlation between the real and predicted values for both edges, positive edges only, and negative edges only.
A logical vector indicating whether each edge is selected based on the edge_level.
A list of parameters used in the summary.
An object of class cpm.
Other parameters passed to the function.
A character vector indicating the method used to calculate the correlation between the real and predicted values.
A numeric value between 0 and 1 indicating the proportional threshold for edge selection.
An object of class cpm_summary.