cpm objectTidy a cpm object
# S3 method for cpm
tidy(x, ..., component = c("performance", "edges"))A tibble with columns storing parameters of the
cpm() object and further columns depending on the component argument:
For component = "performance":
The method used to calculate the correlation between the real and predicted values.
The correlation between the real and predicted values for positive edges.
The correlation between the real and predicted values for negative edges.
For component = "edges":
The proportional threshold for edge selection.
A logical vector indicating whether each edge is selected based on the edge_level (positive).
A logical vector indicating whether each edge is selected based on the edge_level (negative).
A cpm object.
Additional arguments passed to summary().
A character vector indicating the component to tidy.