A cpm object is returned by fit() when fitting a cpm_spec() on a
single dataset.
Structure
A cpm object is a list with the following elements:
callMatched call used for fitting.
specThe originating
cpm_specobject.modelTrained CPM model components used by prediction.
realObserved behavior values after preprocessing decisions.
predMatrix of in-sample predictions (
both,pos,neg).edgesStored edge selection output according to
return_edges.foldsList of row indices used for fitting. For single-fit, this contains one element with all included cases.
paramsParameter list used at fit time.