Connectome Predictive Modelling (CPM) (Shen et al. (2017) tools:::Rd_expr_doi("10.1038/nprot.2016.178")) is a method to predict individual differences in behaviour from brain functional connectivity. 'cpmr' provides a simple yet efficient implementation of this method.
Maintainer: Liang Zhang psychelzh@outlook.com (ORCID)
Useful links: